\name{RPPAFit}
\alias{RPPAFit}
\title{ Fit Dilution Curves to Protein Lysate Series }
\description{
  \code{RPPAFit} fits a four-parameter logistic model to the dilution
  series in a reverse-phase protein array experiment. Individual sample
  concentrations are estimated by matching individual sample dilution
  series to the overall logistic response for the slide.  
}
\usage{
RPPAFit(rppa, design, measure, xform=function(x) x,
    method = c("pure", "mixed", "quantiles", "rlm"),
    ci = FALSE, ignoreNegative = TRUE, bayesian = FALSE,
    trace = FALSE, verbose = FALSE, veryVerbose = FALSE,
    warnLevel = 0)
}
\arguments{
  \item{rppa}{An \code{\link{RPPA}} object containing the raw data to be fit.}
  \item{design}{A \code{\link{RPPADesign}} object describing the layout
    of the array.}
  \item{measure}{A character string identifying the column of the raw
    RPPA data that should be used to fit to the model.}
  \item{xform}{(Experimental) A function that takes a single input
    vector and returns a single output vector of the same length.  The
    \code{measure} column is transformed using this function before
    fitting the model. NOT YET IMPLEMENTED.}
  \item{method}{optional parameter specifying the method for fitting the
    parameters \code{alpha} and \code{beta}.  Default method is
    \code{pure}, which simply uses the optimal fit based on nonlinear
    least squares. Setting \code{method} to \code{mixed} uses \code{nls}
    to fit the three general model parametrs, but uses \code{rlm} to fit
    the sample-specific parameters.  Setting \code{method} to
    \code{quantiles} uses the 5th and 95th quantiles from the raw
    data. Setting \code{method} to \code{rlm} tries to refit the values
    (afer an appropriate transformation) with a robust linear model.}
  \item{ci}{A logical value: if TRUE, then compute 90\% confidence
    intervals on the concentration estimates.}
  \item{ignoreNegative}{A logical value: if TRUE, then negative values
    are converted to NA before fitting the model.}
  \item{bayesian}{ A logical value: if TRUE, we use bayesian methods to
    estimate per sample values of the lower bound alpha.}
  \item{trace}{this is passed to \link{nls} in the bayesian portion of
    the routine.}
  \item{verbose}{ a logical value; if TRUE, the function prints updates
    while it is fitting the data.}
  \item{veryVerbose}{ a logical value; if TRUE, then the function prints
    voluminous updates as it is fitting each individual dilution series.}
  \item{warnLevel}{ used to set the \code{warn} option before calling
    \code{rlm}.  Since this is wrapped in a \code{try} function, it
    won't cause failure but will give us a chance to figure out which
    dilution series are failing.  Setting \code{warnLevel} to two or
    greater may change the values returned by the function.}
}
\details{
  The basic mathematical  model is given by \deqn{Y   = \alpha +
    \beta*g(\gamma*(X+\delta_i)),} where \eqn{Y} is the observed
  intensity and \eqn{X} is the designed dilution step.  The heart of the
  model is the function
  \eqn{g(x) =  \frac{e^x}{1+e^x}}{g(x) =  e^x/(1+e^x)},
  which is the inverse of the logistic function
  \deqn{f(x) = \log(p/(1-p)).}
  By fitting a joint model, we assume that the parameters \eqn{\alpha},
  \eqn{\beta}, and \eqn{\gamma} are the same for all dilution series on
  the array.  The real point of the model, however, is to be able to
  draw inferences on the \eqn{\delta_i}, which represent the (log)
  concentrations of the protein present in different dilution series.
  
  As the first step in fitting the model, we get crude estimates of the
  parameters \eqn{\alpha} and \eqn{\beta} by computing the min and max
  of the observed intensities \eqn{Y}.  We then perform a
  logistic transformation, working with the values
  \eqn{W = f((Y - \alpha)/\beta)}.  We then compute an initial estimate
  of \eqn{\gamma} as the median (over all dilution series) of the slope
  of a robust linear fit to \eqn{W} as a function of the dilution steps
  \eqn{X}. Initial estimates of the individual \eqn{\delta_i} are also
  computed robustly, conditional on the previously estimated parameters.

  The next step depends on which \code{method} has been specified for
  model fitting.  If \code{method="pure"} or \code{method="mixed"}, then
  we use the non-linear least squares function \code{nls}.  Conditional
  on the current estimates of the \eqn{\delta_i}, we use \code{nls} to
  update the estimates of the other three parameters. Then, conditional
  on the updated values of \eqn{\alpha}, \eqn{\beta}, and \eqn{\gamma},
  we update the estimates of the \eqn{\delta_i} one dilution series at a
  time.  The update uses \code{nls} when \code{method="pure"} and uses
  \code{rlm} when \code{method="mixed"}.

  If \code{method='quantiles'}, then we retain quantile estimates of
  \eqn{\alpha} and \eqn{\beta}.  In this case, we first use \code{nls}
  to update the value of \eqn{\gamma} and then, conditional on that
  estimate, update the \eqn{\delta_i}.

  If \code{method="rlm"}, we first follow the procedure described for
  \code{method='nls'}.  We follow this by trying to refit the estimates
  of \eqn{\alpha} and \eqn{\beta} using a robust linear model with the
  \code{rlm} function from the \code{MASS} package.  This computation is
  peformed conditionally on the estimates of \code{\gamma} and
  \code{\delta_i}, in which case the observed intensities \eqn{Y} are
  linear in the sigmoid-transformed dilution steps \eqn{X}.

  The \code{bayesian} option alters the model by assuming that the
  baseline level \eqn{\alpha} can be different for each dilution
  series.  The globally estimated \eqn{\alpha} is used as a strong
  prior, and the individual estimates of \eqn{alpha} are shrunk toward
  the global value.  This idea is motivated by the possibility that
  background levels might be different on different parts of the reverse
  phase protein array.

  If the \code{ci} argument is set to TRUE, then the function also
  computes confidence intervals around the estimates of the log
  concentration.  Since this step can be time-consuming, it is not
  performed by default.  Moreover, confidence intervals can be computed
  after the main model is fit and evaluated, using the
  \code{\link{getConfidenceInterval}} function; see its documentation
  for details on how the intervals are estimated.
}
\value{
  This function constructs and returns an object of the
  \code{\link{RPPAFit}} class.
}
\references{KRC}
\author{Kevin R. Coombes <kcoombes@mdanderson.org>}
\seealso{ \code{\link{RPPAFit-class}}, \code{\link{RPPA}},
  \code{\link{RPPADesign}} }
\examples{
path <- system.file("rppaTumorData", package="SuperCurve")
erk2 <- RPPA("ERK2.txt", path=path)
design <- RPPADesign(erk2, grouping="blockSample",
                     controls=list("neg con", "pos con"))
fit.nls <- RPPAFit(erk2, design, "Mean.Net")
summary(fit.nls)
coef(fit.nls)
}
\keyword{models}
\keyword{regression}
\keyword{nonlinear}
\keyword{robust}
